<?php
/**
 * @file
 * Entity API property declarations.
 */

/**
 * Implements hook_entity_property_info().
 */
function acton_profile_entity_property_info() {
  $info = array();

  // Define profile properties.
  $properties = &$info['acton_profile']['properties'];
  $properties['pid'] = array(
    'label' => t('Profile ID'),
    'description' => t('The serial identifier of the profile.'),
    'type' => 'integer',
    'schema field' => 'pid',
  );
  $properties['machine_name'] = array(
    'label' => t('Machine name'),
    'description' => t('The machine-readable profile name.'),
    'type' => 'token',
    'required' => TRUE,
    'schema field' => 'machine_name',
  );
  $properties['name'] = array(
    'label' => t('Name'),
    'description' => t('The human-readable name of the profile.'),
    'type' => 'text',
    'setter callback' => 'entity_property_verbatim_set',
    'required' => TRUE,
    'schema field' => 'name',
  );
  $properties['data'] = array(
    'label' => t('Data'),
    'type' => 'struct',
    'setter callback' => 'entity_property_verbatim_set',
    // Define data properties. Entity API auto-merges properties defined under
    // the same array path.
    'property info' => acton_profile_default_data_properties(),
  );

  // Define global properties.
  $info['site']['properties']['current_acton_profile'] = array(
    'label' => t('Active site profile'),
    'description' => t('The currently active Acton site profile. To change a profile, set this to a different profile.'),
    'type' => 'acton_profile',
    'getter callback' => 'acton_profile_page_metadata_get_properties',
    'setter callback' => 'acton_profile_page_metadata_set_properties',
    'options list' => 'acton_profile_options_list',
  );
  $info['site']['properties']['current_acton_metadata'] = array(
    'label' => t('Acton metadata'),
    'description' => t('Page metadata for use in the Acton theme to configure page elements, such as keywords and date last modified.'),
    'getter callback' => 'acton_profile_page_metadata_get_properties',
    'setter callback' => 'acton_profile_page_metadata_set_properties',
    'type' => 'struct',
    'property info' => array(),
    'property info alter' => 'acton_profile_page_metadata_property_info_alter',
  );
  $info['site']['properties']['acton_alert_message'] = array(
    'label' => t('Acton metadata'),
    'description' => t('Page metadata for use in the Acton theme to configure page elements, such as keywords and date last modified.'),
    'getter callback' => 'acton_profile_page_metadata_get_properties',
    'setter callback' => 'acton_profile_page_metadata_set_properties',
    'type' => 'text_formatted',
    'property info' => entity_property_text_formatted_info(),
  );

  return $info;
}

/**
 * Returns default profile data properties.
 */
function acton_profile_default_data_properties() {
  // Define properties.
  $properties['site_short_name'] = array(
    'label' => t('Site short name'),
    'description' => t('An optionally shorter version of the site title to appear in the browser title bar and the search box title.'),
    'type' => 'text',
    'setter callback' => 'entity_property_verbatim_set',
    'required' => TRUE,
  );
  $properties['site_id'] = array(
    'label' => t('Site ID'),
    'description' => t('This is the identifier provided to you when you apply for this site. For a list of possible site IDs, please visit the !site.', array('!site' => '<a href="http://webpublishing.anu.edu.au/steps/registering/site-ids.php" target="_blank">' . t('Web Publishing website') . '</a>')),
    'type' => 'text',
    'setter callback' => 'entity_property_verbatim_set',
  );
  $properties['site_url'] = array(
    'label' => t('Site URL'),
    'description' => t('This is the base URL that the style server links the site title to. Do not include the protcol (e.g. http://). Example site URL: www.anu.edu.au/site'),
    'type' => 'text',
    'setter callback' => 'entity_property_verbatim_set',
    'required' => TRUE,
  );
  $properties['resp_officer'] = array(
    'label' => t('Responsible officer'),
    'description' => t('The position with final responsibility for the site. Should not be role name, not an individual.'),
    'type' => 'text',
    'setter callback' => 'entity_property_verbatim_set',
    'required' => TRUE,
  );
  $properties['resp_officer_address'] = array(
    'label' => t('Responsible officer URL/email'),
    'description' => t('An email address or contact page for the responsible officer. For internal Drupal paths, do not include the leading slash. Email addresses are validated but not obfuscated.'),
    'type' => 'text',
    'setter callback' => 'entity_property_verbatim_set',
    'validation callback' => 'valid_acton_profile_contact_address',
    'required' => TRUE,
  );
  $properties['creator'] = array(
    'label' => t('Creator'),
    'description' => t('Name of the entity responsible for creating the page, defaulting to the site responsible officer.'),
    'type' => 'text',
    'computed' => TRUE,
    'getter callback' => 'acton_profile_property_alternative_get',
    'alternative' => 'resp_officer',
  );
  $properties['creator_address'] = array(
    'label' => t('Creator email'),
    'description' => t('Contact email for the creator, defaulting to the responsible officer email.'),
    'type' => 'text',
    'computed' => TRUE,
    'getter callback' => 'acton_profile_property_alternative_get',
    'alternative' => 'resp_officer_address',
    'validation callback' => 'valid_email_address',
  );
  $properties['site_contact'] = array(
    'label' => t('Site contact'),
    'description' => t('The principal contact for queries relating to the site (e.g. Webmaster).'),
    'type' => 'text',
    'setter callback' => 'entity_property_verbatim_set',
    'required' => TRUE,
  );
  $properties['site_contact_address'] = array(
    'label' => t('Site contact URL/email'),
    'description' => t('An email address or contact page for the site contact. For internal Drupal paths, do not include the leading slash. Email addresses are validated but not obfuscated.'),
    'type' => 'text',
    'setter callback' => 'entity_property_verbatim_set',
    'validation callback' => 'valid_acton_profile_contact_address',
    'required' => TRUE,
  );
  $properties['date_modified'] = array(
    'label' => t('Date modified'),
    'description' => t('The date this site has last changed. This date should reflect the day when the site is officially live. This date will be used if a page does not override it.'),
    'type' => 'date',
    'setter callback' => 'entity_property_verbatim_set',
    'required' => TRUE,
  );
  $properties['meta_description'] = array(
    'label' => t('Default description'),
    'description' => t('Description of the page or site to be used where no page description is provided. A common use of this value is Google search results descripton.'),
    'type' => 'text',
    'setter callback' => 'entity_property_verbatim_set',
  );
  $properties['meta_subject'] = array(
    'label' => t('Default subject'),
    'description' => t('Default subject keywords where no specific keywords can be derived, separated by commas. Note that most search engines ignore this value.'),
    'type' => 'text',
    'setter callback' => 'entity_property_verbatim_set',
  );
  $properties['about_page'] = array(
    'label' => t('About page'),
    'description' => t('Path to the About page. The About page is typically used to indicate the website compliance with standards and any help or instructions specific to using the site. It is NOT the site\'s About us page.'),
    'type' => 'uri',
    'setter callback' => 'entity_property_verbatim_set',
  );

  return $properties;
}
