<?php
/**
 * @file
 * Administration implementations.
 */

/**
 * Acton profile admin UI.
 */
class ActonProfileUIController extends EntityDefaultUIController {
  /**
   * {@inheritdoc}.
   */
  public function hook_menu() {
    $items = parent::hook_menu();

    $file_path = drupal_get_path('module', 'acton_profile') . '/includes';

    $items[$this->path]['title'] = 'Acton site profiles';
    $items[$this->path]['type'] = MENU_LOCAL_TASK;

    $items[$this->path . '/list']['title'] = 'List profiles';

    $items[$this->path . '/add-site-id'] = array(
      'title' => array('Add from site ID'),
      'title callback' => 't',
      'title arguments' => array(),
      'description' => 'Add a new profile by attempting to pre-fill using data from the default style server.',
      'page arguments' => array($this->entityType, NULL, 'add-site-id'),
      'access arguments' => array('create-info', $this->entityType),
    ) + $items[$this->path . '/add'];

    $items[$this->path . '/import']['weight'] = 10;

    $items[$this->path . '/set-default/%acton_profile'] = array(
      'page callback' => 'acton_profile_admin_set_default',
      'page arguments' => array(4),
      'access arguments' => array('administer acton profiles'),
      'type' => MENU_CALLBACK,
      'file' => 'acton_profile.admin.inc',
      'file path' => $file_path,
    );

    return $items;
  }

  /**
   * {@inheritdoc}
   */
  public function overviewForm($form, &$form_state) {
    $form['#attached']['css'][] = drupal_get_path('module', 'acton_profile') . '/acton_profile.css';

    if (!variable_get('acton_profile_default_profile') && $profiles = acton_profile_load_multiple()) {
      // Set first profile as default if none set.
      reset($profiles);
      $key = key($profiles);

      // Redirect with token to force overlay parent refresh.
      drupal_goto($this->path . '/set-default/' . $key, array('query' => array('token' => '')));
    }

    return parent::overviewForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function overviewTable($conditions = array()) {
    $table = parent::overviewTable($conditions);
    $table['#attributes']['class'][] = 'acton-profile-overview-table';
    return $table;
  }

  /**
   * {@inheritdoc}
   */
  protected function overviewTableRow($conditions, $id, $entity, $additional_cols = array()) {
    $row = parent::overviewTableRow($conditions, $id, $entity, $additional_cols);

    $default = variable_get('acton_profile_default_profile');
    if ($entity->machine_name == $default) {
      // Show as default profile.
      $row[0]['data']['#prefix'] = '<span class="default">';
      $row[0]['data']['#suffix'] = ' <span class="label-default">' . t('(default profile)') . '</span></span>';
    }
    else {
      // Show link to set it as active.
      $row[0]['data']['#suffix'] = '<span class="link-set-default">' . l(t('Set default'), 'admin/appearance/acton-profile/set-default/' . $entity->machine_name) . '</span>';
    }

    return $row;
  }
}

/**
 * Sets a profile as default.
 */
function acton_profile_admin_set_default(ActonProfile $profile) {
  variable_set('acton_profile_default_profile', $profile->machine_name);
  acton_profile_clear_cache();

  // Trigger parent page refresh.
  if (module_exists('overlay')) {
    overlay_request_page_refresh();
  }

  drupal_set_message(t('The profile %name has been set as default.', array('%name' => $profile->name)));
  drupal_goto('admin/appearance/acton-profile');
}

/**
 * Builds settings form.
 */
function acton_profile_settings($form, &$form_state) {
  // Build profile form using delegate.
  $controller = acton_profile_style_controller();
  if ($controller instanceof ActonProfileStyleFormInterface) {
    if (!isset($form_state['form_controller'])) {
      $form_state['form_controller'] = $controller->getSettingsFormController();
    }
    $form_controller = $form_state['form_controller'];
    $form = $form_controller->form($form, $form_state);

    // Explicitly define handlers.
    $form['#validate'][] = 'acton_profile_settings_validate';
    $form['#submit'][] = 'acton_profile_settings_submit';
  }
  return $form;
}

/**
 * Validates settings form submission.
 */
function acton_profile_settings_validate($form, &$form_state) {
  if (isset($form_state['form_controller'])) {
    /** @var $delegate ActonProfileSettingsFormControllerInterface */
    $delegate = $form_state['form_controller'];
    $delegate->validate($form, $form_state);
  }
}

/**
 * Processes settings form submission.
 */
function acton_profile_settings_submit($form, &$form_state) {
  if (isset($form_state['form_controller'])) {
    /** @var $delegate ActonProfileSettingsFormControllerInterface */
    $delegate = $form_state['form_controller'];
    $delegate->submit($form, $form_state);

    // Trigger parent page refresh.
    if (module_exists('overlay')) {
      overlay_request_page_refresh();
    }
  }
}
