<?php
/**
 * @file
 * Entity implementations.
 */

/**
 * Acton profile entity class.
 */
class ActonProfile extends Entity {
  /**
   * Serial identifier.
   * @var int
   */
  public $pid;

  /**
   * Machine-readable name.
   * @var string
   */
  public $machine_name;

  /**
   * Profile name.
   * @var string
   */
  public $name;

  /**
   * Profile data array.
   * @var array
   */
  public $data;

  /**
   * Profile settings array.
   * @var array
   */
  public $settings;

  /**
   * Constructs a profile entity.
   */
  public function __construct(array $values = array()) {
    parent:: __construct($values, 'acton_profile');
    if (!empty($values['is_new'])) {
      if (!isset($this->data)) {
        $this->data = array();
      }
      if (!isset($this->settings)) {
        $this->settings = array();
      }
    }
  }

  /**
   * Magic method implementation for backwards compatibility.
   */
  public function __call($name, $arguments) {
    if (method_exists('ActonProfileLegacyAdapter', $name)) {
      return call_user_func_array(array(ActonProfileLegacyAdapter::getInstance($this), $name), $arguments);
    }
  }
}

/**
 * Controller class for Acton profiles.
 */
class ActonProfileController extends EntityAPIControllerExportable {
  /**
   * {@inheritdoc}
   *
   * Loaded profiles are ordered by name.
   */
  protected function buildQuery($ids, $conditions = array(), $revision_id = FALSE) {
    $query = parent::buildQuery($ids, $conditions);
    $query->orderBy('base.name');
    return $query;
  }
}
