<?php
/**
 * @file
 * Legacy functionality.
 */

/**
 * Default profile style version.
 *
 * @deprecated
 */
define('ACTON_PROFILE_STYLE_VERSION', 4);

/**
 * Returns the default style version.
 *
 * @deprecated
 */
function acton_profile_style_version() {
  return variable_get('acton_profile_style_version', ACTON_PROFILE_STYLE_VERSION);
}

/**
 * Returns the theme alert bar message.
 *
 * @deprecated
 */
function acton_profile_get_alert() {
  return acton_profile_get_formatted_alert_message();
}

/**
 * Sets the theme alert bar message.
 *
 * @param mixed $message
 *   String message or formatted text message.
 *
 * @deprecated
 */
function acton_profile_set_alert($message) {
  acton_profile_set_alert_message($message);
}

/**
 * Returns Acton profile data property info.
 *
 * @deprecated
 *   This function no longer does anything.
 */
function acton_profile_get_profile_data() {
  return array();
}

/**
 * Validates style server endpoint.
 *
 * @deprecated
 */
function acton_profile_valid_endpoint($endpoint) {
  return ActonProfileEndpoint::fromUrl("http://$endpoint")->isValid();
}

/**
 * Validates style server endpoint.
 *
 * @deprecated
 */
function acton_profile_valid_base_url($base_url) {
  if (!$base_url || preg_match('`^[^:]+://`', $base_url)) {
    return FALSE;
  }
  return valid_url('http://' . $base_url);
}

/**
 * Validates ANU site ID.
 *
 * @deprecated
 */
function acton_profile_valid_site_id($site_id, $endpoint = NULL) {
  $site_ids = &drupal_static(__FUNCTION__);
  if (!isset($site_ids[$site_id])) {
    if (!isset($endpoint)) {
      $endpoint_base = variable_get('acton_profile_default_endpoint_base', ACTON_PROFILE_DEFAULT_ENDPOINT_BASE);
      $endpoint_suffix = variable_get('acton_profile_default_endpoint_suffix', ACTON_PROFILE_DEFAULT_ENDPOINT_SUFFIX);
      $endpoint = $endpoint_base . $endpoint_suffix;
    }
    $json = acton_profile_remote_fetch_json($endpoint, $site_id);
    $site_ids[$site_id] = isset($json['sitevars']['status']);
  }
  return $site_ids[$site_id];
}

/**
 * Get the HTML content for a style part.
 *
 * @param string $part
 *   The name of the part to get as defined in the style guide.
 * @param ActonProfile $profile
 *   Profile to part for.
 * @param array $params
 *   Extra HTTP parameters.
 *
 * @return
 *   HTML content.
 *
 * @deprecated
 */
function acton_profile_remote_get_part($part, ActonProfile $profile, array $params = array()) {
  if ($part == 'json') {
    // Abort if trying to fetch 'json'.
    return;
  }
  if (!isset($profile)) {
    // Abort if no profile to get part for.
    return;
  }

  $site_id = $profile->data['site_id'];
  $endpoint = $profile->getServerEndpoint();
  $cached_endpoint = new ActonProfileCachedEndpoint(ActonProfileEndpoint::fromUrl("http://$endpoint"));
  return $cached_endpoint->fetch($site_id, $part, $params);
}

/**
 * Get formats for fetching page parts.
 *
 * @deprecated
 */
function acton_profile_get_fetch_formats() {
  return array(
    'html' => t('HTML parts'),
    'json' => t('JSON'),
  );
}

/**
 * Fetch a page style part for a profile.
 *
 * @param string $part
 *   Name of the page part to fetch.
 * @param ActonProfile $profile
 *   Profile to fetch.
 * @param $format
 *   Format to fetch and process. Can be 'json' or 'html'.
 * @param array $params
 *   Extra HTTP parameters.
 *
 * @return
 *   Page part HTML content.
 *
 * @deprecated
 */
function acton_profile_remote_fetch_part($part, ActonProfile $profile, $format = 'json', array $params = array()) {
  $endpoint = $profile->getServerEndpoint();
  $site_id = $profile->data['site_id'];
  $ver = $profile->getStyleVersion();
  $params += array('ver' => $ver);

  // Fetch part depending on given format.
  if ($format == 'json') {
    $json = acton_profile_remote_fetch_json($endpoint, $site_id, $params);
    return is_string($json[$part]) ? $json[$part] : NULL;
  }
  elseif ($format == 'html') {
    return acton_profile_remote_fetch_site_part($endpoint, $site_id, $part, $params);
  }
}

/**
 * Fetch a page part through a specified method.
 *
 * @param string $endpoint
 *   Style server endpoint (not including the protocol).
 * @param $site_id
 *   ANU site ID.
 * @param string $part
 *   Name of the part to fetch.
 * @param array $params
 *   Extra HTTP parameters.
 *
 * @return
 *   Part content.
 *
 * @deprecated
 */
function acton_profile_remote_fetch_site_part($endpoint, $site_id, $part, array $params = array()) {
  // Fetch using legacy direct GET method.
  $method = 'direct_get';
  return acton_profile_remote_fetch_part_method($endpoint, $site_id, $part, $method, $params);
}

/**
 * Fetch a JSON array for a site ID.
 *
 * @param string $endpoint
 *   Style server endpoint (not including the protocol).
 * @param $site_id
 *   ANU site ID.
 * @param array $params
 *   Extra HTTP parameters.
 *
 * @return
 *   Site JSON array.
 *
 * @deprecated
 */
function acton_profile_remote_fetch_json($endpoint, $site_id, array $params = array()) {
  if ($json = acton_profile_remote_fetch_site_part($endpoint, $site_id, 'json', $params)) {
    $json_array = drupal_json_decode($json);
    if (is_array($json_array) && !empty($json_array)) {
      return $json_array;
    }
  }
}

/**
 * Fetch a part through a specified method.
 *
 * @param string $endpoint
 *   Style server endpoint (not including the protocol).
 * @param $site_id
 *   ANU site ID.
 * @param string $part
 *   Name of the part to fetch.
 * @param $method
 *   Fetch method. Must match a method declared in hook_acton_profile_fetch_methods().
 *
 * @return
 *   Part content.
 *
 * @deprecated
 */
function acton_profile_remote_fetch_part_method($endpoint, $site_id, $part, $method, array $params = array()) {
  // Fetch.
  $methods = acton_profile_remote_get_fetch_methods();
  if (isset($methods[$method]) && function_exists($callback = $methods[$method]['fetch callback'])) {
    if ($result = $callback($endpoint, $site_id, $part, $params)) {
      return $result;
    }
  }
}

/**
 * Direct fetch callback.
 *
 * @param string $endpoint
 *   Style server endpoint (not including the protocol).
 * @param $site_id
 *   ANU site ID.
 * @param string $part
 *   Name of the part to fetch.
 * @param array $params
 *   Extra HTTP parameters.
 *
 * @deprecated
 */
function acton_profile_remote_fetch_direct_get($endpoint, $site_id, $part, array $params = array()) {
  return ActonProfileEndpoint::fromUrl("http://$endpoint")->fetch($site_id, $part, $params);
}

/**
 * Construct base URL for direct fetch.
 *
 * @deprecated
 */
function acton_profile_remote_fetch_direct_get_url($endpoint, array $params = array()) {
  $params += array(
    // Use default legacy version.
    'ver' => ACTON_PROFILE_STYLE_VERSION,
  );
  return ActonProfileEndpoint::fromUrl("http://$endpoint")->getUrl($params);
}

/**
 * Direct fetch callback.
 *
 * @param string $endpoint
 *   Style server endpoint (not including the protocol).
 * @param $site_id
 *   ANU site ID.
 * @param string $part
 *   Name of the part to fetch.
 * @param array $params
 *   Extra HTTP parameters.
 *
 * @deprecated
 */
function acton_profile_remote_fetch_cache_get($endpoint, $site_id, $part, array $params = array()) {
  $bin = 'cache_acton_profile';
  $expire = variable_get('acton_profile_cache_lifetime', ACTON_PROFILE_DEFAULT_CACHE_LIFE);
  $cached_endpoint = new ActonProfileCachedEndpoint(ActonProfileEndpoint::fromUrl("http://$endpoint"), $bin, $expire);
  return $cached_endpoint->fetch($site_id, $part, $params);
}

/**
 * Get an array of fetch method info declarations.
 *
 * @deprecated
 */
function acton_profile_remote_get_fetch_methods() {
  return array(
    'direct_get' => array(
      'label' => t('Direct (via HTTP GET)'),
      'fetch callback' => 'acton_profile_remote_fetch_direct_get',
      'weight' => -10,
    ),
    'cache_get' => array(
      'label' => t('Cached GET'),
      'fetch callback' => 'acton_profile_remote_fetch_cache_get',
      'weight' => -5,
    ),
  );
}

/**
 * Legacy profile entity operation container.
 *
 * @deprecated
 */
final class ActonProfileLegacyAdapter {
  /**
   * Wrapped settings array.
   */
  private $settings;

  /**
   * Prevents the adapter from being constructed.
   */
  private function __construct(ActonProfile $profile) {
    $this->settings = &$profile->settings;
  }

  /**
   * Returns a singleton instance.
   */
  public static function getInstance(ActonProfile $profile) {
    $instances = &drupal_static(__METHOD__, array());
    $hash = spl_object_hash($profile);
    if (!isset($instances[$hash])) {
      $instances[$hash] = new ActonProfileLegacyAdapter($profile);
    }
    return $instances[$hash];
  }

  /**
   * Determines the style server endpoint base to use.
   *
   * @deprecated
   */
  public function getServerEndpointBase(array $submitted = array()) {
    $base = isset($submitted['server_endpoint_base']) ? $submitted['server_endpoint_base'] : $this->settings['server_endpoint_base'];
    $override = isset($submitted['server_override']) ? $submitted['server_override'] : $this->settings['server_override'];
    if (!$override || !$base) {
      $base = variable_get('acton_profile_default_endpoint_base', ACTON_PROFILE_DEFAULT_ENDPOINT_BASE);
    }
    return $base;
  }

  /**
   * Determines the style server endpoint suffix to use.
   *
   * @deprecated
   */
  public function getServerEndpointSuffix(array $submitted = array()) {
    $suffix = isset($submitted['server_endpoint_suffix']) ? $submitted['server_endpoint_suffix'] : $this->settings['server_endpoint_suffix'];
    $override = isset($submitted['server_override']) ? $submitted['server_override'] : $this->settings['server_override'];
    if (!$override || !$suffix) {
      $suffix = variable_get('acton_profile_default_endpoint_suffix', ACTON_PROFILE_DEFAULT_ENDPOINT_SUFFIX);
    }
    return $suffix;
  }

  /**
   * Determines the style server endpoint to use.
   *
   * @deprecated
   */
  public function getServerEndpoint(array $submitted = array()) {
    // Extract fetch parameters from profile.
    $endpoint_base = $this->getServerEndpointBase($submitted);
    $endpoint_suffix = $this->getServerEndpointSuffix($submitted);
    if (!acton_profile_valid_endpoint($endpoint = $endpoint_base . $endpoint_suffix)) {
      // Fall back to hard-coded default.
      $endpoint = ACTON_PROFILE_DEFAULT_ENDPOINT_BASE . ACTON_PROFILE_DEFAULT_ENDPOINT_SUFFIX;
    }

    return $endpoint;
  }

  /**
   * Returns the style version for this profile.
   *
   * @deprecated
   */
  public function getStyleVersion() {
    return !empty($this->settings['style_version']) ? $this->settings['style_version'] : acton_profile_style_version();
  }
}

/**
 * Builds the profile data entry form.
 *
 * @deprecated
 *   This function no longer does anything.
 */
function acton_profile_get_profile_data_form(&$form, &$form_state, ActonProfile $profile, $op = 'edit') {}

/**
 * Defines legacy theme info.
 *
 * @deprecated
 */
function _acton_profile_legacy_theme() {
  return array(
    'acton_remote_part' => array(
      'render element' => 'acton_remote_part',
    ),
  );
}

/**
 * Defines legacy element types.
 *
 * @deprecated
 */
function _acton_profile_legacy_element_info() {
  return array(
    'acton_remote_part' => array(
      '#part' => NULL,
      '#profile' => NULL,
      '#params' => array(),
      '#theme' => 'acton_remote_part',
    ),
  );
}

/**
 * Insert variables for remote part.
 */
function template_preprocess_acton_remote_part(&$variables) {
  $element = &$variables['acton_remote_part'];
  $variables['element'] = &$element;
  $variables['part'] = $element['#part'];
}

/**
 * Render the part content.
 *
 * @param $variables
 *   Variables to render:
 *   - 'element': The source render array.
 *   - 'part': The page part to render.
 *
 * @return
 *   HTML content.
 */
function theme_acton_remote_part(&$variables) {
  $element = &$variables['element'];
  $part = $element['#part'];
  $profile = $element['#profile'];
  $params = $element['#params'];

  // Sanity checks
  if ($part && is_object($profile) && $profile instanceof ActonProfile && is_array($params)) {
    $variables['content'] = acton_profile_remote_get_part($part, $profile, $params);
  }

  return $variables['content'];
}
