<?php
/**
 * @file
 * Acton Profile theme declaration and processing functions.
 */

/**
 * Defines theme hooks.
 */
function _acton_profile_theme($existing, $type, $theme, $path) {
  $base = array(
    'path' => drupal_get_path('module', 'acton_profile') . '/theme',
    'file' => 'acton_profile.theme.inc',
  );

  // Define profile hooks.
  $hooks['acton_anu_head'] = array(
      'variables' => array('profile' => NULL),
    ) + $base;
  $hooks['acton_anu_body_header'] = array(
      'variables' => array(
        'profile' => NULL,
        'utility' => array(),
        'utility_placeholder' => '<!--GW_UTILITIES-->',
        'tabs' => array(),
        'tabs_placeholder' => '<!-- TABS -->',
        'mega' => array(),
        'mega_placeholder' => '<!--GW_NAV_WRAP-->',
      ),
    ) + $base;
  $hooks['acton_anu_body_footer'] = array(
      'variables' => array('profile' => NULL),
    ) + $base;
  $hooks['acton_page_requisite'] = array(
      'variables' => array('profile' => NULL, 'part' => ''),
    ) + $base;

  // Define template hooks.
  $hooks['acton_head'] = array(
      'variables' => array(
        'identifier' => '',
        'title' => '',
        'description' => '',
        'subject' => '',
        'date_modified' => '',
        'creator' => '',
        'creator_address' => '',
      ),
      'template' => 'acton-head',
    ) + $base;
  $hooks['acton_alert_bar'] = array(
      'variables' => array('message' => ''),
      'template' => 'acton-alert-bar',
    ) + $base;
  $hooks['acton_banner_tabs'] = array(
      'variables' => array('links' => array()),
      'template' => 'acton-banner-tabs',
    ) + $base;
  $hooks['acton_hnav_mega'] = array(
      'variables' => array('profile' => NULL, 'menu' => NULL, 'utility_menu' => NULL),
      'template' => 'acton-hnav-mega',
    ) + $base;
  $hooks['acton_hnav_mega_menu'] = array(
      'variables' => array('profile' => NULL, 'menus' => array()),
      'template' => 'acton-hnav-mega-menu',
    ) + $base;
  $hooks['acton_hnav_mobile_menu'] = array(
      'variables' => array('profile' => NULL, 'nav' => array(), 'tree' => array(), 'local_search' => TRUE),
      'template' => 'acton-hnav-mobile-menu',
    ) + $base;
  $hooks['acton_hnav_mobile_menu_nav'] = array(
      'variables' => array('profile' => NULL),
      'template' => 'acton-hnav-mobile-menu-nav',
    ) + $base;
  $hooks['acton_utility_menu'] = array(
      'variables' => array('menu' => ''),
      'template' => 'acton-utility-menu',
    ) + $base;
  $hooks['acton_responsive_menu'] = array(
      'variables' => array('menu_icon_src' => '', 'search_box_mini' => array()),
      'template' => 'acton-responsive-menu',
    ) + $base;
  $hooks['acton_search_box'] = array(
      'variables' => array('site_short_name' => '', 'search_site_name' => ''),
      'template' => 'acton-search-box',
    ) + $base;
  $hooks['acton_search_box_mini'] = array(
      'variables' => array('search_site_name' => ''),
      'template' => 'acton-search-box-mini',
    ) + $base;
  $hooks['acton_site_footer'] = array(
      'variables' => array(
        'resp_officer' => '',
        'resp_officer_address' => '',
        'site_contact' => '',
        'site_contact_address' => '',
        'date_modified' => '',
        'about_page' => '',
      ),
      'template' => 'acton-site-footer',
    ) + $base;

  // Define legacy deprecated hooks.
  $hooks += _acton_profile_legacy_theme();

  return $hooks;
}

/**
 * Implements hook_preprocess_acton_page_requisite().
 */
function template_preprocess_acton_page_requisite(&$variables) {
  if ($variables['part']) {
    // Add template suggestion.
    $variables['theme_hook_suggestions'][] = 'acton_page_requisite__' . $variables['part'];
  }
}

/**
 * Renders a page part.
 */
function theme_acton_page_requisite($variables) {
  // Retrieve style part.
  if ($profile = $variables['profile']) {
    $controller = acton_profile_style_controller();
    if ($controller instanceof ActonProfileStyleControllerInterface) {
      $backend = $controller->getBackend($profile);
      if ($backend instanceof ActonProfileBackendInterface) {
        return $backend->getStylePart($variables['part']);
      }
    }
  }

  return '';
}

/**
 * Sanitizes page metadata variables.
 */
function template_process_acton_head(&$variables) {
  // Validate creator email.
  if (!valid_email_address($variables['creator_address'])) {
    $variables['creator_address'] = '';
  }

  // Sanitize the rest.
  $clean = array('identifier', 'title', 'description', 'subject', 'date_modified', 'creator', 'creator_address');
  _acton_clean_variables($variables, $clean);
}

/**
 * Renders remote ANU header resources.
 */
function theme_acton_anu_head(&$variables) {
  return theme('acton_page_requisite', array(
    'part' => 'meta',
    'profile' => $variables['profile'],
  ));
}

/**
 * Renders page body banner.
 */
function theme_acton_anu_body_header(&$variables) {
  // Render page part.
  $banner = theme('acton_page_requisite', array(
    'part' => 'banner',
    'profile' => $variables['profile'],
  ));

  // Insert menus.
  if ($variables['utility']) {
    $banner = str_replace($variables['utility_placeholder'], render($variables['utility']), $banner);
  }
  if ($variables['tabs']) {
    $banner = str_replace($variables['tabs_placeholder'], render($variables['tabs']), $banner);
  }
  if ($variables['mega']) {
    $banner = str_replace($variables['mega_placeholder'], render($variables['mega']), $banner);
  }

  return $banner;
}

/**
 * Renders page body footer.
 */
function theme_acton_anu_body_footer(&$variables) {
  return theme('acton_page_requisite', array(
    'part' => 'footer',
    'profile' => $variables['profile'],
  ));
}

/**
 * Prepares variables for search box.
 */
function template_preprocess_acton_search_box(&$variables) {
  $variables['search_name'] = urlencode($variables['search_site_name']);
}

/**
 * Sanitizes variables for search box.
 */
function template_process_acton_search_box(&$variables) {
  _acton_clean_variables($variables, array('site_short_name', 'search_name'));
}

/**
 * Adds horizontal banner tab behavior.
 */
function template_preprocess_acton_banner_tabs($variables) {
  drupal_add_js(drupal_get_path('module', 'acton_profile') . '/js/acton_banner_tabs.js');
}

/**
 * Prepares tab links for horizontal banner tabs.
 */
function template_process_acton_banner_tabs(&$variables) {
  // Process menu links into tab links.
  $variables['tab_links'] = array();
  foreach ($variables['links'] as $name => $link) {
    $link['acton_banner_tab'] = TRUE;
    $variables['tab_links'][$name] = l($link['title'], $link['href'], $link);
  }
}

/**
 * Processes mega navigation menus.
 */
function template_preprocess_acton_hnav_mega(&$variables) {
  $variables['tabs'] = array(
    '#prefix' => '<div id="gw-nav-links"><ul>',
    '#suffix' => '</ul></div>',
  );
  $variables['tab_wrapper_attributes'] = array(
    'id' => 'tabs-wrap',
    'role' => 'navigation',
  );
  $variables['mega_menu'] = array(
    '#theme' => 'acton_hnav_mega_menu',
    '#profile' => $variables['profile'],
    '#menus' => array(),
  );

  $tree = menu_tree_all_data($variables['menu']);
  $active_trail = array();
  foreach (menu_get_active_trail() as $item) {
    // Skip matching active trail if the active page is not in the specified menu.
    if (isset($item['menu_name']) && $item['menu_name'] != $variables['menu'] && $item['menu_name'] != $variables['utility_menu']) {
      $active_trail = array();
      break;
    }

    $active_trail[] = isset($item['mlid']) ? $item['mlid'] : 0;
  }

  // Add home link by default.
  $variables['tabs']['home'] = array(
    '#theme' => 'link',
    '#path' => '<front>',
    '#text' => t('Home'),
    '#options' => array('attributes' => array('class' => array('tabs-home'))),
    '#prefix' => '<li>',
    '#suffix' => '</li>',
  );

  $wrap_tab = variable_get('acton_hnav_mega_tab_wrap');
  if ($wrap_tab) {
    $variables['tab_wrapper_attributes']['class'][] = 'tabs-wrap-2line';
  }

  $mega_menu_id = 1;
  $mega_menu_blocks = variable_get('acton_hnav_mega_menu_blocks', array());
  $mobile_only_settings = variable_get('acton_megamenu_mobile_only', array());
  foreach ($tree as $item) {
    if (!$item['link']['access'] || $item['link']['hidden']) {
      // Skip hidden item.
      continue;
    }
    if (!empty($mobile_only_settings[$item['link']['mlid']])) {
      // Skip mobile-only item.
      continue;
    }

    $mlid = $item['link']['mlid'];

    // Add tab link.
    $element['#theme'] = 'link';
    $element['#path'] = $item['link']['href'];
    $element['#options'] = !empty($item['link']['localized_options']) ? $item['link']['localized_options'] : array();
    $element['#options'] += array('attributes' => array());
    if ($item['link']['href'] == '<front>') {
      $element['#options']['attributes']['class'][] = 'tabs-home';
      // Remove default home link.
      unset($variables['tabs']['home']);
    }
    elseif (in_array($item['link']['mlid'], $active_trail)) {
      $element['#options']['attributes']['class'][] = 'gw-select';
    }
    if ($wrap_tab) {
      if ($tab_cache = cache_get("acton_hnav_mega_tab_wrap:$mlid")) {
        $tab_title = $tab_cache->data;
      }
      else {
        $tab_title = _acton_hnav_wrap_link_text($item['link']['title']);
        cache_set("acton_hnav_mega_tab_wrap:$mlid", $tab_title);
      }
      $element['#options']['html'] = TRUE;
      $element['#text'] = $tab_title;
    }
    else {
      $element['#options']['html'] = FALSE;
      $element['#text'] = $item['link']['title'];
    }

    $link_item = array(
      'link' => $element,
      '#prefix' => '<li>',
      '#suffix' => '</li>',
    );
    if ($item['link']['href'] == '<front>') {
      // Add home link to the start.
      $variables['tabs'] = array($mlid => $link_item) + $variables['tabs'];
    }
    else {
      $variables['tabs'][$mlid] = $link_item;
    }

    // Add mega menu.
    foreach ($item['below'] as $subitem) {
      if (!$subitem['link']['access'] || $subitem['link']['hidden']) {
        // Skip hidden item.
        continue;
      }
      if (!empty($mobile_only_settings[$subitem['link']['mlid']])) {
        // Skip mobile-only item.
        continue;
      }

      // Add mega menu link.
      $element['#theme'] = 'link';
      $element['#text'] = $subitem['link']['title'];
      $element['#path'] = $subitem['link']['href'];
      $element['#options'] = !empty($subitem['link']['localized_options']) ? $subitem['link']['localized_options'] : array();
      $element['#options'] += array('attributes' => array());
      $element['#options']['html'] = FALSE;
      if (in_array($subitem['link']['mlid'], $active_trail)) {
        $element['#options']['attributes']['class'][] = 'gw-select';
      }

      $variables['mega_menu']['#menus'][$mega_menu_id]['links'][$subitem['link']['mlid']] = $element;
    }

    // Add in-menu components.
    if (!empty($mega_menu_blocks[$mlid]['left_heading'])) {
      $variables['mega_menu']['#menus'][$mega_menu_id]['left']['heading']['#prefix'] = '<h1>';
      $variables['mega_menu']['#menus'][$mega_menu_id]['left']['heading']['link'] = array(
        '#theme' => 'link',
        '#text' => $mega_menu_blocks[$mlid]['left_heading'],
        '#path' => $item['link']['href'],
        '#options' => array('html' => FALSE, 'attributes' => array()),
      );
      $variables['mega_menu']['#menus'][$mega_menu_id]['left']['heading']['#suffix'] = '</h1>';
    }
    if (!empty($mega_menu_blocks[$mlid]['left_body'])) {
      $variables['mega_menu']['#menus'][$mega_menu_id]['left']['body']['#markup'] = filter_xss_admin($mega_menu_blocks[$mlid]['left_body']);
    }
    if (!empty($variables['mega_menu']['#menus'][$mega_menu_id]['left'])) {
      $variables['mega_menu']['#menus'][$mega_menu_id]['left']['#prefix'] = $item['link']['href'] == current_path()
        ? '<div class="gw-mega-t1 gw-select">'
        : '<div class="gw-mega-t1">';
      $variables['mega_menu']['#menus'][$mega_menu_id]['left']['#suffix'] = '</div>';
    }
    if (!empty($mega_menu_blocks[$mlid]['right'])) {
      $variables['mega_menu']['#menus'][$mega_menu_id]['right'] = _acton_hnav_mega_render_block($mega_menu_blocks[$mlid]['right']);
    }
    if (!empty($mega_menu_blocks[$mlid]['bottom'])) {
      $variables['mega_menu']['#menus'][$mega_menu_id]['bottom'] = _acton_hnav_mega_render_block($mega_menu_blocks[$mlid]['bottom']);
    }

    // Fill in defaults.
    if (!empty($variables['mega_menu']['#menus'][$mega_menu_id])) {
      $variables['mega_menu']['#menus'][$mega_menu_id] += array(
        'links' => array(),
        'left' => array(),
        'right' => array(),
        'bottom' => array(),
      );

      // Force left block to show.
      if (empty($variables['mega_menu']['#menus'][$mega_menu_id]['left'])) {
        $variables['mega_menu']['#menus'][$mega_menu_id]['left']['#markup'] = '&nbsp;';
      }

      // Trigger megamenu if not empty.
      $variables['tabs'][$item['link']['mlid']]['link']['#options']['attributes']['id'] = 'gw-mega-tab-' . $mega_menu_id;
      $variables['tabs'][$item['link']['mlid']]['link']['#options']['attributes']['data-mega-menu-trigger'] = $mega_menu_id;
    }

    $mega_menu_id ++;
  }

  // Add mobile menu tree.
  $mobile_menu_tree = _acton_hnav_build_mobile_menu_tree($tree, $active_trail);
  $data = menu_tree_all_data($variables['utility_menu'], NULL, 2);
  foreach ($data as $item) {
    if (!$item['link']['hidden']) {
      $mlid = $item['link']['mlid'];

      $element['#theme'] = 'link';
      $element['#text'] = $item['link']['title'];
      $element['#path'] = $item['link']['href'];
      $element['#options'] = !empty($item['link']['localized_options']) ? $item['link']['localized_options'] : array();
      $element['#options'] += array('attributes' => array());
      if (in_array($mlid, $active_trail)) {
        $element['#options']['attributes']['class'][] = 'gw-select';
      }
      $element['#options']['html'] = FALSE;

      $mobile_menu_tree[$mlid]['#prefix'] = '<li>';
      $mobile_menu_tree[$mlid]['#suffix'] = '</li>';
      $mobile_menu_tree[$mlid]['link'] = $element;

      $submenu_links = array();
      foreach ($item['below'] as $subitem) {
        // Add mega menu links.
        if ($subitem['link']['access'] && !$subitem['link']['hidden']) {
          // Add tab link.
          $element['#theme'] = 'link';
          $element['#text'] = $subitem['link']['title'];
          $element['#path'] = $subitem['link']['href'];
          $element['#options'] = !empty($subitem['link']['localized_options']) ? $subitem['link']['localized_options'] : array();
          $element['#options'] += array('attributes' => array());
          $element['#options']['html'] = FALSE;
          if (in_array($subitem['link']['mlid'], $active_trail)) {
            $element['#options']['attributes']['class'][] = 'gw-select';
          }

          $submenu_links[$subitem['link']['mlid']]['#prefix'] = '<li>';
          $submenu_links[$subitem['link']['mlid']]['#suffix'] = '</li>';
          $submenu_links[$subitem['link']['mlid']]['link'] = $element;
        }
      }
      if ($submenu_links) {
        $submenu_links['#prefix'] = '<ul>';
        $submenu_links['#suffix'] = '</ul>';
        $mobile_menu_tree[$mlid]['below'] = $submenu_links;
      }
    }
  }

  $variables['mobile_menu'] = array(
    '#theme' => 'acton_hnav_mobile_menu',
    '#profile' => $variables['profile'],
    '#tree' => array(
        '#prefix' => '<ul class="gw-mega-mobile-list">',
        '#suffix' => '</ul>',
      ) + $mobile_menu_tree,
  );

  // Determine if the menu is hidden or not
  $menu_items_enabled = TRUE;
  foreach ($tree as $item) {
    if ($menu_items_enabled = !$item['link']['hidden']) {
      break;
    }
  }

  $variables['menu_hidden'] = FALSE;

  if (empty($tree) || !$menu_items_enabled) {
    $variables['menu_hidden'] = TRUE;
  }

  drupal_add_js(drupal_get_path('module', 'acton_profile') . '/js/acton_profile.js', array('group' => JS_THEME));
}

/**
 * Wraps link text into two lines.
 */
function _acton_hnav_wrap_link_text($text) {
  if ($search = strpos($text, ' ')) {
    // Search for a space closest to the midpoint.
    $position = 0;
    $midpoint = strlen($text) / 2;
    $shortest = $midpoint;
    do {
      $distance = abs($search + 1 - $midpoint);
      if ($distance < $shortest) {
        $shortest = $distance;
        $position = $search + 1;
      }
      else {
        break;
      }
    }
    while (FALSE !== $search = strpos($text, ' ', $position));

    return check_plain(substr($text, 0, $position - 1)) . '<br>' . check_plain(substr($text, $position));
  }

  return check_plain($text);
}

/**
 * Renders a megamenu block.
 */
function _acton_hnav_mega_render_block($id) {
  list($block_module, $block_delta) = explode('-', $id, 2);
  if ($block = block_load($block_module, $block_delta)) {
    $block_view = module_invoke($block_module, 'block_view', $block_delta);
    drupal_alter(array('block_view', "block_view_{$block_module}_{$block_delta}"), $block_view, $block);

    $result = array();
    if (!empty($block_view['content'])) {
      // Move block title into special heading.
      if (!empty($block_view['subject'])) {
        $result['heading'] = array(
          '#prefix' => '<h1>',
          '#markup' => check_plain($block_view['subject']),
          '#suffix' => '</h1>',
        );
      }
      $block_view['subject'] = '';

      $block_build = is_array($block_view['content'])
        ? $block_view['content']
        : array('#markup' => $block_view['content']);
      $block_build += array(
        '#block' => (object) ($block_view + (array) $block),
      );
      $block_build['#theme_wrappers'][] = 'block';
      $result['block'] = $block_build;
    }

    return $result;
  }
}

/**
 * Builds mobile menu tree.
 */
function _acton_hnav_build_mobile_menu_tree($tree, $active_trail) {
  $output = array();
  foreach ($tree as $item) {
    if ($item['link']['access'] && !$item['link']['hidden']) {
      $element['#theme'] = 'link';
      $element['#text'] = $item['link']['title'];
      $element['#path'] = $item['link']['href'];
      $element['#options'] = !empty($item['link']['localized_options']) ? $item['link']['localized_options'] : array();
      $element['#options'] += array('attributes' => array());
      if (in_array($item['link']['mlid'], $active_trail)) {
        $element['#options']['attributes']['class'][] = 'gw-select';
      }
      $element['#options']['html'] = FALSE;

      $output[$item['link']['mlid']]['#prefix'] = '<li>';
      $output[$item['link']['mlid']]['#suffix'] = '</li>';
      $output[$item['link']['mlid']]['link'] = $element;
      if ($item['below']) {
        $output[$item['link']['mlid']]['below'] = $item['below'] ? _acton_hnav_build_mobile_menu_tree($item['below'], $active_trail) : $item['below'];;
      }
    }
  }
  if (!empty($output)) {
    $output['#prefix'] = '<ul>';
    $output['#suffix'] = '</ul>';
  }
  return $output;
}

/**
 * Processes mega menu blocks.
 */
function template_preprocess_acton_hnav_mega_menu(&$variables) {
  $variables['close_img_url'] = '';

  if ($profile = $variables['profile']) {
    $controller = acton_profile_style_controller();
    if ($controller instanceof ActonProfileStyleControllerInterface) {
      $backend = $controller->getBackend($profile);
      if ($backend instanceof ActonProfileBackendInterface) {
        $variables['close_img_url'] = $backend->getResourceUrl('${style_version}/images/buttons/btn-close-white.gif');
      }
    }
  }

  // Split menu link lists.
  foreach ($variables['menus'] as $menu_id => $menu) {
    $variables['menus'][$menu_id]['link_blocks'] = array();

    $links = array();
    foreach ($menu['links'] as $mlid => $link) {
      $links[$mlid] = array(
        '#prefix' => '<li>',
        'link' => $link,
        '#suffix' => '</li>',
      );
    }

    if ($links) {
      $column_count = empty($menu['right']) ? 3 : 2;
      foreach (array_chunk($links, ceil(count($links) / $column_count)) as $column) {
        $variables['menus'][$menu_id]['link_blocks'][] = array(
          '#theme_wrappers' => array('container'),
          '#attributes' => array('class' => array('nopadtop nopadbottom gw-mega-t2 narrow')),
          'list' => array(
            '#prefix' => '<ul>',
            'links' => $column,
            '#suffix' => '</ul>',
          ),
        );
      }
    }
  }
}

/**
 * Processes mobile mega menu.
 */
function template_preprocess_acton_hnav_mobile_menu(&$variables) {
  $variables += array('nav' => array());
  $variables['nav'] += array(
    '#theme' => 'acton_hnav_mobile_menu_nav',
    '#profile' => $variables['profile'],
  );
  $variables['search_sel_arrow_img_src'] = '';
  $variables['search_name'] = '';

  if ($profile = $variables['profile']) {
    $variables['search_name'] = check_plain($profile->settings['search_site_name']);
    $controller = acton_profile_style_controller();
    if ($controller instanceof ActonProfileStyleControllerInterface) {
      $backend = $controller->getBackend($profile);
      if ($backend instanceof ActonProfileBackendInterface) {
        $variables['search_sel_arrow_img_src'] = $backend->getResourceUrl('${style_version}/images/buttons/arrow-down-black.png');
      }
    }
  }
}

/**
 * Processes mobile mega menu bar.
 */
function template_preprocess_acton_hnav_mobile_menu_nav(&$variables) {
  $variables['menu_img_src'] = '';
  $variables['search_img_src'] = '';

  if ($profile = $variables['profile']) {
    $controller = acton_profile_style_controller();
    if ($controller instanceof ActonProfileStyleControllerInterface) {
      $backend = $controller->getBackend($profile);
      if ($backend instanceof ActonProfileBackendInterface) {
        $variables['menu_img_src'] = $backend->getResourceUrl('${style_version}/images/buttons/menu-white.png');
        $variables['search_img_src'] = $backend->getResourceUrl('${style_version}/images/buttons/search-white.png');
      }
    }
  }
}

/**
 * Processes utility menu.
 */
function template_preprocess_acton_utility_menu(&$variables) {
  $active_trail = array();
  foreach (menu_get_active_trail() as $item) {
    // Skip matching active trail if the active page is not in the specified menu.
    if (isset($item['menu_name']) && $item['menu_name'] != $variables['menu']) {
      $active_trail = array();
      break;
    }

    $active_trail[] = isset($item['mlid']) ? $item['mlid'] : 0;
  }

  $data = menu_tree_all_data($variables['menu'], NULL, 1);
  $variables['links'] = array();
  foreach ($data as $item) {
    if (!$item['link']['access'] || $item['link']['hidden']) {
      // Skip hidden top item.
      continue;
    }

    $mlid = $item['link']['mlid'];

    $element['#theme'] = 'link';
    $element['#text'] = $item['link']['title'];
    $element['#path'] = $item['link']['href'];
    $element['#options'] = !empty($item['link']['localized_options']) ? $item['link']['localized_options'] : array();
    $element['#options'] += array('attributes' => array());
    if (in_array($mlid, $active_trail)) {
      $element['#options']['attributes']['class'][] = 'gw-select';
    }
    $element['#options']['html'] = FALSE;

    $variables['links'][$mlid]['#prefix'] = '<li>';
    $variables['links'][$mlid]['#suffix'] = '</li>';
    $variables['links'][$mlid]['link'] = $element;
  }
  if ($variables['links']) {
    $variables['links']['#prefix'] = '<ul class="bnr-gw-util">';
    $variables['links']['#suffix'] = '</ul>';
  }
}

/**
 * Prepares variables for the small search box.
 */
function template_preprocess_acton_search_box_mini(&$variables) {
  // Prepares search as regular search box.
  template_preprocess_acton_search_box($variables);
}

/**
 * Sanitizes variables for the small search box.
 */
function template_process_acton_search_box_mini(&$variables) {
  _acton_clean_variables($variables, array('search_name'));
}

/**
 * Prepares variables for the site footer that precedes body footer.
 */
function template_preprocess_acton_site_footer(&$variables) {
  // Clean up site footer.
  if (valid_email_address($variables['resp_officer_address'])) {
    $variables['resp_officer_address'] = 'mailto:' . $variables['resp_officer_address'];
  }
  if (valid_email_address($variables['site_contact_address'])) {
    $variables['site_contact_address'] = 'mailto:' . $variables['site_contact_address'];
  }
}

/**
 * Finalizes variables for the site footer that precedes body footer.
 */
function template_process_acton_site_footer(&$variables) {
  $clean = array('resp_officer', 'resp_officer_address', 'site_contact', 'site_contact_address', 'date_modified');
  _acton_clean_variables($variables, $clean);

  // Populate site footer parts.
  $variables['parts'] = array();
  if ($variables['date_modified']) {
    $variables['parts']['date_modified'] = array(
      '#prefix' => '<span class="upd-date">',
      '#markup' => t('Updated:') . '&nbsp;&nbsp;<strong>' . $variables['date_modified'] . '</strong>',
      '#suffix' => '</span>',
    );
  }
  if ($variables['resp_officer'] && $variables['resp_officer_address']) {
    $variables['parts']['resp_officer'] = array(
      '#prefix' => '<span class="upd-officer">',
      '#markup' => t('Responsible Officer:') . '&nbsp;&nbsp;' . l('<strong>' . $variables['resp_officer'] . '</strong>', $variables['resp_officer_address'], array(
          'html' => TRUE,
          'external' => $variables['resp_officer_address'][0] == '/' ? TRUE : NULL,
        )),
      '#suffix' => '</span>',
    );
  }
  if ($variables['site_contact'] && $variables['site_contact_address']) {
    $variables['parts']['site_contact'] = array(
      '#prefix' => '<span class="upd-contact">',
      '#markup' => t('Page Contact:') . '&nbsp;&nbsp;' . l('<strong>' . $variables['site_contact'] . '</strong>', $variables['site_contact_address'], array(
          'html' => TRUE,
          'external' => $variables['site_contact_address'][0] == '/' ? TRUE : NULL,
        )),
      '#suffix' => '</span>',
    );
  }
}